@@ -285,7 +285,10 @@ class VariableClUpdateOutdateSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
-        return self.Get('cl_update_other_set')
+        if (self.Get('cl_update_other_set') == 'on' and
+            self.Get('cl_update_other_rep_name')):
+            return "on"
+        return "off"
 
 class VariableClUpdateMetadataForce(Variable):
     """
