@@ -142,7 +142,7 @@ class Wsdl(WsdlBase):
             # категория метода
             'category': __('Configuration'),
             # заголовок метода
-            'title': __("The Update Check"),
+            'title': __("Update Check"),
             # иконка для графической консоли
             'image': 'software-properties,preferences-desktop',
             # метод присутствует в графической консоли
